" Menu Translations:	Simplified Chinese (Windows)
" Last Change:		Tue Sep  4 11:26:52 CST 2001

" $LANG  on Windows 95/98/NT is Chinese(GB)_GB.936
" $LANG  on Windows 2000/ME is Chinese_GB.936
" Source the other one from here.
source <sfile>:p:h/menu_chinese_gb.936.vim
